@@ -19,14 +19,18 @@ def upload(fqdn,login,incoming,files_to_upload,debug,compress,
 	command += ['-o', anopt]
     # TV-Note: Are these / Should these be escaped?
     command += files_to_upload
-    command.append('%s@%s:%s' % (login, fqdn, incoming))
+    if login and login != '*':
+      login_spec = '%s@'%login
+    else:
+      login_spec = ''
+    command.append('%s%s:%s' % (login_spec, fqdn, incoming))
     change_mode = 0
     for file in files_to_upload:
         if not stat.S_IMODE(os.lstat(file)[stat.ST_MODE])==0644:
             change_mode = 1
     if debug:
-        print "D: Uploading with scp to %s@%s:%s" % \
-            (login, fqdn, incoming)
+        print "D: Uploading with scp to %s%s:%s" % \
+            (login_spec, fqdn, incoming)
         print "D: %s" % command
     if dputhelper.spawnv(os.P_WAIT, '/usr/bin/scp', command):
         print "Error while uploading."
@@ -35,8 +39,11 @@ def upload(fqdn,login,incoming,files_to_upload,debug,compress,
         fix_command = ['ssh']
     	for anopt in ssh_config_options:
 		fix_command += ['-o', anopt]
-	fix_command += ['%s@%s' % (login, fqdn), 'chmod', '0644'] \
+	fix_command += ['%s%s' % (login_spec, fqdn), 'chmod', '0644'] \
  		        + files_to_fix
+	if debug:
+	  print "D: Fixing some permissions"
+          print "D: %s" % fix_command
         if dputhelper.spawnv(os.P_WAIT, '/usr/bin/ssh', fix_command):
-            print "Error while fixing permission."
+            print "Error while fixing permissions."
             sys.exit(1)
